@@ -1,30 +1,15 @@
 # pylint: disable=E1101
 
 # imports - compatibility imports
-from pipupgrade         import _compat
-from pipupgrade._compat import zip
+from pipupgrade             import _compat
+from pipupgrade._compat     import zip, _is_python_version
+from pipupgrade.util._dict  import dict_from_list
 
 # imports - standard imports
 import sys
 import inspect
-
-def merge_dict(*args):
-    merged = dict()
-
-    for arg in args:
-        copy = arg.copy()
-        merged.update(copy)
-
-    return merged
-    
-def list_filter(v, filter_):
-    filtered = filter(filter_, v)
-    filtered = list(filtered)
-
-    return filtered
-
-def dict_from_list(keys, values):
-    return dict(zip(keys, values))
+import collections
+import itertools
 
 def get_function_arguments(fn):
     # https://stackoverflow.com/a/2677263
@@ -34,7 +19,7 @@ def get_function_arguments(fn):
     if _compat.PY2:
         argspec_getter = inspect.getargspec
         success        = True
-    if _compat.PYTHON_VERSION >= (3,0) and (3,4) <= _compat.PYTHON_VERSION:
+    if _compat.PYTHON_VERSION >= (3,0) and _compat.PYTHON_VERSION < (3,5):
         argspec_getter = inspect.getfullargspec
         success        = True
 
@@ -53,4 +38,15 @@ def get_function_arguments(fn):
     if not success:
         raise ValueError("Unknown Python Version {} for fetching functional arguments.".format(sys.version))
 
-    return params
\ No newline at end of file
+    return params
+
+def auto_typecast(value):
+    str_to_bool = lambda x: { "True": True, "False": False, "None": None}[x]
+
+    for type_ in (str_to_bool, int, float):
+        try:
+            return type_(value)
+        except (KeyError, ValueError, TypeError):
+            pass
+
+    return value
\ No newline at end of file
